#pragma optimize("Ofast")

#include <iostream>
#include <cmath>
#include <numeric>
#include <algorithm>
#include <vector>
#include <cstdint>
#include <set>
#include <cassert>
#include <map>
using namespace std;

#ifdef MYC
#define dPRINT(a) {cout << "DEBUG " << a << endl;}
#else
#define dPRINT(a)
#endif

using i64 = int64_t;
using i128 = __int128;

struct State {
    i128 alive = 0;
    i64 frozen = 0;

    i64 time = 0;

    [[nodiscard]] inline i128 summary() const { return alive + frozen; }
};


enum { MUL = 2, ADD = 1 };

int main() {
    i64 n, m;
    cin >> n >> m;

    vector<pair<i64, i64>> events(2 * n);
    vector<State> states(2 * n);

    vector<int> a(n);
    for (int i = 0; i < n; ++i) {
        cin >> a[i];

        events[i] = { a[i], ADD };
    }

    vector<int> t(n);
    for (int i = 0; i < n; ++i) {
        cin >> t[i];

        events[i + n] = { t[i] + a[i], MUL };
    }

    sort(events.begin(), events.end());

    i64 last = 0;
    State pstate = {};
    int state_size = 0;

    for (int i = 0; i < events.size(); ++i) {
        State nstate = pstate;
        nstate.time = events[i].first;

        nstate.alive = nstate.alive * (static_cast<i128>(1LL) << (events[i].first - last));
        if (events[i].second == ADD) { // add
            nstate.frozen++;
        }
        else {
            nstate.frozen--;
            nstate.alive += 2;
        }

        if (pstate.time == nstate.time)
            states[state_size - 1] = nstate;
        else
            states[state_size++] = nstate;

        pstate = nstate;
        last = events[i].first;

        if (nstate.summary() > m)
            break;
    }
    states.resize(state_size);

    auto[alive, frozen, time] = states[state_size - 2];

    auto need = m - frozen;

    while (alive < need && alive) {
        alive *= 2;
        time++;
    }

    if (alive != need || need < 0)
        cout << -1 << endl;
    else
        cout << time << endl;

    return 0;
}