#pragma optimize("Ofast")

#include <iostream>
#include <cmath>
#include <numeric>
#include <algorithm>
#include <vector>
#include <cstdint>
#include <set>
#include <cassert>
#include <map>
using namespace std;

#ifdef MYC
#define dPRINT(a) {cout << "DEBUG " << a << endl;}
#else
#define dPRINT(a)
#endif

using i64 = int64_t;

struct State{
    i64 alive = 0;
    i64 frozen = 0;

    i64 time = 0;

    inline i64 summary() const {return alive + frozen;}
};

enum {MUL=2, ADD=1};

int main() {
    i64 n, m;
    cin >> n >> m;

    vector<pair<i64, i64>> events(2 * n);
    vector<State> states(2 * n);

    vector<int> a(n);
    for (int i = 0; i < n; ++i) {
        cin >> a[i];

        events[i] = {a[i], ADD};
    }

    vector<int> t(n);
    for (int i = 0; i < n; ++i) {
        cin >> t[i];

        events[i + n] = {t[i] + a[i], MUL};
    }

    sort(events.begin(), events.end());

    i64 last = 0;
    State pstate = {};
    int state_size = 0;

    for (int i = 0; i < events.size(); ++i) {
        State nstate = pstate;
        nstate.time = events[i].first;

        if (events[i].second == ADD) { // add
            nstate.frozen++;
            nstate.alive = nstate.alive * (1LL << (events[i].first - last));
        } else {
            nstate.frozen--;
            nstate.alive = nstate.alive * (1LL << (events[i].first - last)) + 2;
        }

        if(pstate.time == nstate.time)
            states[state_size-1] = nstate;
        else
            states[state_size++] = nstate;

        dPRINT(nstate.alive << ' ' << nstate.frozen << ' ' << nstate.time << ' ' << (events[i].first - last));
        pstate  = nstate;
        last = events[i].first;
    }
    states.resize(state_size);

    i64 it;
    {
        i64 l = 0, r = states.size();
        i64 need = m;

        while (r - l > 1) {
            auto mid = (l + r) / 2;

            if (states[mid].summary() <= need)
                l = mid;
            else
                r = mid;
        }

        it = l;
    }

    if (states[it].summary() == m) {
        cout << states[it].time << endl;

        return 0;
    }
    if (it == states.size() - 1) { // после всех действий
        i64 backteries = states.back().summary();
        i64 time = states.back().time;
        while (backteries * 2 < m){
            if(backteries * 2 < backteries){
                cout << -1 << endl;
                return  0;
            }

            backteries *= 2;
            time++;
        }
        if(backteries == m)
        cout << time << endl;
        else
            cout << -1 << endl;
        return  0;
    }
    else { // между двумя
        auto[alive, frozen, btime] = states[it];

        i64 l = 0, r = states[it+1].time - btime;

        i64 need = m - frozen;

        while(r-l>1){
            auto mid = (r+l)/2;

            if(alive*(1LL<<mid) <= need)
                l = mid;
            else
                r = mid;
        }

        if (alive*(1LL<<l)!=need){
            cout << -1 << endl;
            return 0;
        }else{
            cout << l + btime << endl;
            return 0;
        }
    }

    return 0;
}